zms.zmssqldb.ZMSSqlDb

Package zms :: Module zmssqldb :: Class ZMSSqlDb |
[frames] | no frames]

# Class ZMSSqlDb

    zms.zmscustom.ZMSCustom --+
                              |
                             ZMSSqlDb

Instance Methods
filteredChildNodes(self, REQUEST={}, meta_types=None) |
getModelContainer(self) |
getModel(self) |
setModel(self, newModel) |
record_encode__(self, cols, record, encoding='utf-8') |
getDA(self) |
sql_quote__(self, tablename, columnname, v) |
commit(self) |
rollback(self) |
execute(self, sql, params=(), max_rows=0, encoding=None) |
substitute_params(self, sql, params=()) |
assemble_query_result(self, res, encoding=None) |
query(self, sql, max_rows=0, encoding=None) |
executeQuery(self, sql) |
getEntityPK(self, tableName) |
getEntityRecordHandler(self, tableName, stereotypes=['*']) |
getEntityColumn(self, tableName, columnName, row=None) |
getEntity(self, tableName) |
getEntities(self) |
recordSet_Select(self, tablename, select=None, where=None) |
recordSet_Init(self, REQUEST) |
assembleFilter(self, l) |
recordSet_Filter(self, REQUEST) |
recordSet_Sort(self, REQUEST) |
getFk(self, tablename, id, name, value, createIfNotExists=1) |
recordSet_Insert(self, tablename, values={}, update_intersections=False) |
recordSet_Update(self, tablename, rowid, values={}, old_values={}, update_intersections=False) |
recordSet_UpdateIntersections(self, tablename, rowid, values={}) |
recordSet_Delete(self, tablename, rowid) |
delete_blob(self, auth_user, tablename, id, rowid, REQUEST=None, RESPONSE=None) ZMSSqlDb.delete_blob |
set_blob(self, auth_user, tablename, id, rowid=None, xml=None, REQUEST=None, RESPONSE=None) ZMSSqlDb.set_blob |
get_blob(self, tablename, id, rowid, REQUEST=None, RESPONSE=None) ZMSSqlDb.get_blob |
manage_changeProperties(self, lang, REQUEST=None, RESPONSE=None) ZMSSqlDb.manage_changeProperties |
ajaxGetObjOptions(self, REQUEST) ObjAttrs.ajaxGetObjOptions |
ajaxGetAutocompleteColumns(self, tableName, fmt=None, REQUEST=None) ZMSSqlDb.ajaxGetAutocompleteColumns |
manage_changeConfiguration(self, lang, btn='', key='all', REQUEST=None, RESPONSE=None) ZMSSqlDb.manage_changeConfiguration |

Class Variables
| security = `ClassSecurityInfo()`
| meta_id = `"ZMSSqlDb"`
| meta_type = `"ZMSSqlDb"`
| manage_options = `{'label': 'TAB_EDIT', 'action': 'manage_main'`...``
| __authorPermissions__ = `'manage', 'manage_main', 'manage_main_`...``
| __administratorPermissions__ = `'manage_properties', 'manage_ch`...``
| __ac_permissions__ = `'ZMS Author', __authorPermissions__, ('ZM`...``
| manage_zmi_input_form = `PageTemplateFile('zpt/ZMSSqlDb/input_f`...``
| manage_zmi_details_grid = `PageTemplateFile('zpt/ZMSSqlDb/zmi_d`...``
| manage_zmi_details_form = `PageTemplateFile('zpt/ZMSSqlDb/zmi_d`...``
| manage_zmi_lazy_select_form = `PageTemplateFile('zpt/ZMSSqlDb/z`...``
| manage_main = `PageTemplateFile('zpt/ZMSSqlDb/manage_main', glo`...``
| manage_properties = `PageTemplateFile('zpt/ZMSSqlDb/manage_prop`...``
| manage_configuration = `PageTemplateFile('zpt/ZMSSqlDb/manage_c`...``
| valid_types = `{'blob': {}, 'date': 1, 'datetime': 1, 'details'`...``

Class Variable Details

  ### manage_options Value:
      {'label': 'TAB_EDIT', 'action': 'manage_main'}, {'label': 'TAB_PROPERT
      IES', 'action': 'manage_properties'}, {'label': 'TAB_CONFIGURATION', '
      action': 'manage_configuration'},

  ### __authorPermissions__ Value:
      'manage', 'manage_main', 'manage_main_iframe', 'manage_workspace', 'ma
      nage_moveObjUp', 'manage_moveObjDown', 'manage_moveObjToPos', 'manage_
      cutObjects', 'manage_copyObjects', 'manage_pasteObjs', 'manage_userFor
      m', 'manage_user', 'manage_zmi_input_form', 'manage_zmi_details_grid',
       'manage_zmi_details_form', 'manage_zmi_lazy_select_form',

  ### __administratorPermissions__ Value:
      'manage_properties', 'manage_changeProperties', 'manage_changeTempBlob
      jProperty', 'manage_configuration', 'manage_changeConfiguration',

  ### __ac_permissions__ Value:
      'ZMS Author', __authorPermissions__, ('ZMS Administrator', __administr
      atorPermissions__),

  ### manage_zmi_input_form Value:
      PageTemplateFile('zpt/ZMSSqlDb/input_form', globals())

  ### manage_zmi_details_grid Value:
      PageTemplateFile('zpt/ZMSSqlDb/zmi_details_grid', globals())

  ### manage_zmi_details_form Value:
      PageTemplateFile('zpt/ZMSSqlDb/zmi_details_form', globals())

  ### manage_zmi_lazy_select_form Value:
      PageTemplateFile('zpt/ZMSSqlDb/zmi_lazy_select_form', globals())

  ### manage_main Value:
      PageTemplateFile('zpt/ZMSSqlDb/manage_main', globals())

  ### manage_properties Value:
      PageTemplateFile('zpt/ZMSSqlDb/manage_properties', globals())

  ### manage_configuration Value:
      PageTemplateFile('zpt/ZMSSqlDb/manage_configuration', globals())

  ### valid_types Value:
      {'blob': {}, 'date': 1, 'datetime': 1, 'details': {}, 'fk': {}, 'html'
      : 1, 'multiselect': {}, 'multimultiselect': {}, 'pk': 1, 'checkbox': 1
      , 'password': 1, 'richtext': 1, 'text': 1, 'time': 1, 'url': 1,}